==> org.jresearch.commons.gwt.flexess-1.0.2.jar: org/jresearch/commons/gwt/flexess/client/model/meta/RoleTemplateModel.java <==
package org.jresearch.commons.gwt.flexess.client.model.meta;

import java.util.List;

import org.jresearch.commons.gwt.client.model.DomainNewModel;

public class RoleTemplateModel extends DomainNewModel<String> {

	private static final long serialVersionUID = -5705542024857825838L;

	private String modelId;
	private List<PermissionTemplateModel> permissionTemplates;
	private boolean customized;

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		final StringBuilder builder = new StringBuilder();
		builder.append("RoleTemplateModel ["); //$NON-NLS-1$
		if (getModelId() != null) {
			builder.append("getModelId()=").append(getModelId()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		builder.append("isCustomized()=").append(isCustomized()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		if (getPermissionTemplates() != null) {
			builder.append("getPermissionTemplates()=").append(getPermissionTemplates()); //$NON-NLS-1$
		}
		builder.append("]"); //$NON-NLS-1$
		return builder.toString();
	}

	/**
	 * @return the modelId
	 */
	public String getModelId() {
		return modelId;
	}

	/**
	 * @param modelId
	 *            the modelId to set
	 */
	public void setModelId(final String modelId) {
		this.modelId = modelId;
	}

	/**
	 * @return the permissionTemplates
	 */
	public List<PermissionTemplateModel> getPermissionTemplates() {
		return permissionTemplates;
	}

	/**
	 * @param permissionTemplates
	 *            the permissionTemplates to set
	 */
	public void setPermissionTemplates(final List<PermissionTemplateModel> permissionTemplates) {
		this.permissionTemplates = permissionTemplates;
	}

	/**
	 * @return the customized
	 */
	public boolean isCustomized() {
		return customized;
	}

	/**
	 * @param customized
	 *            the customized to set
	 */
	public void setCustomized(final boolean customized) {
		this.customized = customized;
	}

}

==> org.jresearch.commons.gwt.flexess-1.0.8.jar: org/jresearch/commons/gwt/flexess/client/model/meta/RoleTemplateModel.java <==
package org.jresearch.commons.gwt.flexess.client.model.meta;

import java.util.List;

import org.jresearch.commons.gwt.shared.model.DomainNewModel;

public class RoleTemplateModel extends DomainNewModel<String> {

	private static final long serialVersionUID = -5705542024857825838L;

	private String modelId;
	private List<PermissionTemplateModel> permissionTemplates;
	private boolean customized;

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		final StringBuilder builder = new StringBuilder();
		builder.append("RoleTemplateModel ["); //$NON-NLS-1$
		if (getModelId() != null) {
			builder.append("getModelId()=").append(getModelId()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		builder.append("isCustomized()=").append(isCustomized()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		if (getPermissionTemplates() != null) {
			builder.append("getPermissionTemplates()=").append(getPermissionTemplates()); //$NON-NLS-1$
		}
		builder.append("]"); //$NON-NLS-1$
		return builder.toString();
	}

	/**
	 * @return the modelId
	 */
	public String getModelId() {
		return modelId;
	}

	/**
	 * @param modelId
	 *            the modelId to set
	 */
	public void setModelId(final String modelId) {
		this.modelId = modelId;
	}

	/**
	 * @return the permissionTemplates
	 */
	public List<PermissionTemplateModel> getPermissionTemplates() {
		return permissionTemplates;
	}

	/**
	 * @param permissionTemplates
	 *            the permissionTemplates to set
	 */
	public void setPermissionTemplates(final List<PermissionTemplateModel> permissionTemplates) {
		this.permissionTemplates = permissionTemplates;
	}

	/**
	 * @return the customized
	 */
	public boolean isCustomized() {
		return customized;
	}

	/**
	 * @param customized
	 *            the customized to set
	 */
	public void setCustomized(final boolean customized) {
		this.customized = customized;
	}

}
